RespQueryHelper class final

A helper class used to get the current size of the device

Constructors

RespQueryHelper({required BuildContext context})
The constructor that will accept the current build context
const

Properties

context → BuildContext
Buidld context of the widget requesting query
final
currentBreakpoint → RespBreakpoint
Get the current breakpoint of the device based on the width of the device
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
Get the current width of the device
no setter

Methods

getWidth(double percentage) → double
Get a portion of the current device width (Using percentage value of current device width)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited